Shader "Custom/BumpSpecTessPhong" {
Properties {
	_EdgeLength ("Edge length", Range(2,50)) = 15
	_Color ("Main Color", Color) = (1,1,1,1)
	_SpecColor ("Specular Color", Color) = (0.5, 0.5, 0.5, 1)
	_Shininess ("Shininess", Range (0.03, 1)) = 0.078125
	_MainTex ("Base (RGB) Gloss (A)", 2D) = "white" {}
	_DispTex ("Disp Texture", 2D) = "black" {}
	_Displacement ("Displacement", Range(0, 1.0)) = 0.3
	_Phong ("Phong Strengh", Range(0,1)) = 0.5
	_BumpMap ("Normalmap", 2D) = "bump" {}
	_MaxDist ("Max Dist", Float) = 1
}
SubShader { 
	Tags { "RenderType"="Opaque" }
	LOD 400
	
CGPROGRAM
#pragma surface surf BlinnPhong vertex:disp tessellate:tessEdge tessphong:_Phong nolightmap addshadow
#pragma exclude_renderers flash
#pragma target 5.0
#pragma debug

#include "Tessellation.cginc"

struct appdata {
	float4 vertex : POSITION;
	float4 tangent : TANGENT;
	float3 normal : NORMAL;
	float2 texcoord : TEXCOORD0;
};

float _Phong;
float _EdgeLength;
float _MaxDist;
float4 tessEdge (appdata v0, appdata v1, appdata v2)
{
    return UnityEdgeLengthBasedTessCull (v0.vertex, v1.vertex, v2.vertex, _EdgeLength, _MaxDist);
}

sampler2D _DispTex;
float4 _DispTex_ST;
float _Displacement;

void disp (inout appdata v)
{
	float2 uv = TRANSFORM_TEX(v.texcoord, _DispTex);
    float d = tex2Dlod(_DispTex, float4(uv, 0, 0)).r * _Displacement;
    v.vertex.xyz += v.normal * d;
}

sampler2D _MainTex;
sampler2D _BumpMap;
fixed4 _Color;
half _Shininess;

struct Input {
	float2 uv_MainTex;
	float2 uv_BumpMap;
};

void surf (Input IN, inout SurfaceOutput o) {
	fixed4 tex = tex2D(_MainTex, IN.uv_MainTex);
	o.Albedo = tex.rgb * _Color.rgb;
	o.Gloss = tex.a;
	o.Alpha = tex.a * _Color.a;
	o.Specular = _Shininess;
	o.Normal = UnpackNormal(tex2D(_BumpMap, IN.uv_BumpMap));
}
ENDCG
}

FallBack "Specular"
}
