using UnityEngine;

public class RenderInto3DCS : MonoBehaviour
{
	public ComputeShader cs;
	public int size = 16;	
	private RenderTexture volume;
		
	void OnDisable ()
	{
		if (volume != null) DestroyImmediate (volume);
		volume = null;
	}
	
	private void CreateResources ()
	{
		if (!volume)
		{
			volume = new RenderTexture (size, size, 0, RenderTextureFormat.ARGB32);
			volume.volumeDepth = size;
			volume.isVolume = true;
			volume.enableRandomWrite = true;
			volume.Create();
			renderer.sharedMaterial.SetTexture ("_Volume", volume);
		}
	}
	
	void Update ()
	{
		if (!SystemInfo.supportsComputeShaders)
		{
			Debug.LogWarning ("Compute shaders not supported (not using DX11?)");
			this.enabled = false;
			return;
		}
		
		CreateResources ();
		
		cs.SetTexture (0, "Result", volume);
		const float threadNumPerDimension = 8.0f;
		int threadGroupsPerDimension = Mathf.FloorToInt (size / threadNumPerDimension);
		cs.Dispatch (0, threadGroupsPerDimension, threadGroupsPerDimension, threadGroupsPerDimension);
	}
}
