using UnityEngine;
using System.Collections.Generic;

public class BlockPool : MonoBehaviour
{
	public Block[] m_Blocks;
	public LightProbes[] m_LightProbes;
	
	private List<Block>[] m_FreeBlocks;
	private int m_NextBlockIndex = -1;
	
	public void Init ()
	{
		m_FreeBlocks = new List<Block>[m_Blocks.Length];
		for (int i = 0; i < m_Blocks.Length; i++)
		{
			m_FreeBlocks[i] = new List<Block> ();
			
			Block block = InstantiateBlock (i);
			block.gameObject.SetActive (false);
			m_FreeBlocks[i].Add(block);
		}
	}
	
	private Block InstantiateBlock (int index)
	{
		Block block = GameObject.Instantiate (m_Blocks[index]) as Block;
		block.index = index;
		return block;
	}
	
	public int GetNextBlockIndex ()
	{
		//return Random.Range (0, m_Blocks.Length);
		m_NextBlockIndex = (m_NextBlockIndex + 1) % m_Blocks.Length;
		return m_NextBlockIndex;
	}
	
	public Block GetBlockAtIndex (int index)
	{
		List<Block> freeBlocksAtIndex = m_FreeBlocks[index];
		Block block;
		if (freeBlocksAtIndex.Count > 0)
		{
			block = freeBlocksAtIndex[0];
			freeBlocksAtIndex.RemoveAt (0);
			Debug.Log ("Returned a block from the pool at index " + index + " (" + freeBlocksAtIndex.Count + " blocks left).");
		}
		else
		{
			block = InstantiateBlock (index);
			Debug.Log ("Created a new block at index " + index + ".");
		}
		
		block.gameObject.SetActive (true);
		return block;
	}
	
	public LightProbes GetLightProbesCopyAtIndex (int index)
	{
		return Instantiate (m_LightProbes[index]) as LightProbes;
	}
	
	public void ReturnBlock (Block block)
	{	
		m_FreeBlocks[block.index].Add (block);
		block.gameObject.SetActive (false);
		Debug.Log ("Returned block at index " + block.index);
	}
}
