using UnityEngine;
using System.Collections.Generic;

public class LightProbeFixer
{
	// patch first light probes from the new set with last light probes from the old set
	public static void PatchLightProbes(LightProbes oldLightProbes, LightProbes lightProbes, Vector3 endPivotLocalOffset, float distEps)
	{
		// no patching needed for the first block
		if (endPivotLocalOffset == Vector3.zero)
			return;
		
		List<int> endLightProbesIndices = new List<int> (6);
		Vector3[] oldLightProbesPositions = oldLightProbes.positions;
		for (int i = 0; i < oldLightProbesPositions.Length; i++)
		{
			if (Mathf.Abs (oldLightProbesPositions[i].x - endPivotLocalOffset.x) < distEps)
			{
				endLightProbesIndices.Add (i);
			}
		}
		
		List<int> startLightProbesIndices = new List<int> (6);
		Vector3[] lightProbePositions = lightProbes.positions;
		for (int i = 0; i < lightProbePositions.Length; i++)
		{
			if (Mathf.Abs (lightProbePositions[i].x) < distEps)
			{
				startLightProbesIndices.Add (i);
			}
		}
		
		const int kCoefficientsPerProbe = 27;
		float[] oldCoefficients = oldLightProbes.coefficients;
		float[] newCoefficients = lightProbes.coefficients;
		
		for (int i = 0; i < startLightProbesIndices.Count; i++)
		{
			int startProbeIndex = startLightProbesIndices[i];
			Vector3 startProbePosition = lightProbePositions[startProbeIndex];
			for (int j = 0; j < endLightProbesIndices.Count; j++)
			{
				int endLightProbeIndex = endLightProbesIndices[j];
				Vector3 endProbePosition = oldLightProbesPositions[endLightProbeIndex];
				Vector3 offsetEndProbePosition = endProbePosition - endPivotLocalOffset;
				
				Vector3 diff = startProbePosition - offsetEndProbePosition;
				
				if (Mathf.Abs (diff.x) < distEps &&
					Mathf.Abs (diff.y) < distEps &&
					Mathf.Abs (diff.z) < distEps)
				{
					int startProbeCoefficientIndex = startProbeIndex * kCoefficientsPerProbe;
					int endProbeCoefficientIndex = endLightProbeIndex * kCoefficientsPerProbe;
					// copy coefficients
					for (int k = 0; k < kCoefficientsPerProbe; k++)
					{
						newCoefficients[startProbeCoefficientIndex + k] = oldCoefficients[endProbeCoefficientIndex + k];
					}
					
					break;
				}
			}
		}
		lightProbes.coefficients = newCoefficients;
	}
}
